@@ -6,7 +6,7 @@ use warnings;
 
 # External packages used by packages in this file, that don't export symbols:
 use only 'Locale::KeyedText' => '1.72.0-';
-use only 'Rosetta' => '0.722.0-';
+use only 'Rosetta' => '0.723.0-';
 
 ###########################################################################
 ###########################################################################
@@ -19,7 +19,7 @@ use only 'Readonly' => '1.03-';
 ###########################################################################
 
 { package Rosetta::Engine::Example; # class
-    use version; our $VERSION = qv('0.722.0');
+    use version; our $VERSION = qv('0.723.0');
 
     # External packages used by the Rosetta::Engine::Example class, that do export symbols:
     use only 'Class::Std' => '0.0.8-';
@@ -53,7 +53,7 @@ Self-contained reference implementation of a Rosetta Engine
 
 =head1 VERSION
 
-This document describes Rosetta::Engine::Example version 0.722.0.
+This document describes Rosetta::Engine::Example version 0.723.0.
 
 =head1 SYNOPSIS
 
@@ -93,7 +93,7 @@ It also requires these Perl 5 classes that are on CPAN:
 L<Locale::KeyedText-(1.72.0...)|Locale::KeyedText> (for error messages).
 
 It also requires these Perl 5 classes that are in the current distribution:
-L<Rosetta-0.722.0|Rosetta>.
+L<Rosetta-0.723.0|Rosetta>.
 
 =head1 INCOMPATIBILITIES
 
@@ -101,7 +101,8 @@ None reported.
 
 =head1 SEE ALSO
 
-I<This documentation is pending.>
+Go to L<Rosetta> for the majority of distribution-internal references, and
+L<Rosetta::SeeAlso> for the majority of distribution-external references.
 
 =head1 BUGS AND LIMITATIONS
 
