@@ -6,7 +6,7 @@ use warnings;
 
 # External packages used by packages in this file, that don't export symbols:
 use only 'Locale::KeyedText' => '1.72.0-';
-use only 'Rosetta' => '0.722.0';
+use only 'Rosetta' => '0.723.0';
 
 ###########################################################################
 ###########################################################################
@@ -19,7 +19,7 @@ use only 'Readonly' => '1.03-';
 ###########################################################################
 
 { package Rosetta::Validator; # module
-    use version; our $VERSION = qv('0.722.0');
+    use version; our $VERSION = qv('0.723.0');
 
     # External packages used by the Rosetta::Validator module, that do export symbols:
     # (None Yet)
@@ -52,7 +52,7 @@ A common comprehensive test suite to run against all Engines
 
 =head1 VERSION
 
-This document describes Rosetta::Validator version 0.722.0.
+This document describes Rosetta::Validator version 0.723.0.
 
 =head1 SYNOPSIS
 
@@ -85,7 +85,7 @@ It also requires these Perl 5 classes that are on CPAN:
 L<Locale::KeyedText-(1.72.0...)|Locale::KeyedText> (for error messages).
 
 It also requires these Perl 5 classes that are in the current distribution:
-L<Rosetta-0.722.0|Rosetta>.
+L<Rosetta-0.723.0|Rosetta>.
 
 =head1 INCOMPATIBILITIES
 
@@ -93,9 +93,8 @@ None reported.
 
 =head1 SEE ALSO
 
-These Perl 5 packages implement Rosetta Engine classes and their test
-suites are the initial main dependents of Rosetta::Validator:
-L<Rosetta::Engine::Example>.
+Go to L<Rosetta> for the majority of distribution-internal references, and
+L<Rosetta::SeeAlso> for the majority of distribution-external references.
 
 =head1 BUGS AND LIMITATIONS
 
