@@ -16,7 +16,7 @@ Readonly my %TEXT_STRINGS => (
 ###########################################################################
 
 { package Rosetta::Validator::L::en; # module
-    use version; our $VERSION = qv('0.160.0');
+    use version; our $VERSION = qv('0.160.1');
     sub get_text_by_key {
         my (undef, $msg_key) = @_;
         return $TEXT_STRINGS{$msg_key};
@@ -40,7 +40,7 @@ Localization of Rosetta::Validator for English
 
 =head1 VERSION
 
-This document describes Rosetta::Validator::L::en version 0.160.0.
+This document describes Rosetta::Validator::L::en version 0.160.1.
 
 =head1 SYNOPSIS
 
@@ -78,7 +78,8 @@ None reported.
 
 =head1 SEE ALSO
 
-I<This documentation is pending.>
+Go to L<Rosetta> for the majority of distribution-internal references, and
+L<Rosetta::SeeAlso> for the majority of distribution-external references.
 
 =head1 BUGS AND LIMITATIONS
 
